import { jsonable } from '../../utils/s.js';
import S from 's-js';
import { createSettings, assignSettings } from '../settings/settings-model.js';

/**
 * The currently visible application page.
 */

var Page;

(function (Page) {
  Page["HOME"] = "";
  Page["WARNINGS"] = "warnings";
  Page["SETTINGS"] = "settings";
})(Page || (Page = {}));
/**
 * Creates a new application state.
 *
 * @param appName name of the application
 */


function createApp(appName = document.title) {
  return {
    currentPage: jsonable(S.value(Page.HOME)),
    settings: createSettings()
  };
}
/**
 * Updates the application state to the given values in a plain JSON object.
 *
 * The update is performed within a single S.js transaction.
 *
 * @param app application state
 * @param plain plain JSON object
 */

function assignApp(app, plain) {
  S.freeze(() => {
    app.currentPage(plain.currentPage);
    assignSettings(app.settings, plain.settings);
  });
}

export { Page, assignApp, createApp };
//# sourceMappingURL=app-model.js.map
