import { createElement, createTextNode, setAttribute, assign, S, content, insert } from 'surplus';
import { bindString, bindNumber } from '../../utils/surplus.js';

// noinspection ES6UnusedImports
const MAX_PERSONS_PER_CONTRIBUTORS = 100;
const MAX_HOURS_PER_WEEK = 7 * 24;
const DRAGGABLE_HANDLE_CLASS = 'draggable-handle';
const PLAINTEXT_CLASS = 'form-control-plaintext form-control-sm w-100';
const INPUT_CLASS = 'form-control form-control-sm w-100';
const INPUT_CLASS_RIGHT = 'form-control form-control-sm text-right'; // Unfortunately, Firefox does not automatically resize <input> element of type number to the maximum required width.
// https://stackoverflow.com/questions/22590483/why-does-adding-min-max-properties-change-the-width-of-a-numeric-html5-input-ele
// As a workaround, we set the width relative to the width of digit '0'. We include some extra digits to account for:
// Padding on the left, padding on the right, and spin buttons.

const INPUT_WIDTH_3_DIGITS = `${4 + Math.ceil(Math.log(MAX_HOURS_PER_WEEK) / Math.LN10)}ch`;
function ContributorView({
  ctrl
}) {
  return function () {
    var __, __div1, __div2, __div2_div1, __div2_insert2, __div2_div3, __div2_div3_input1, __div2_div3_div2, __div2_div3_div2_span1, __button3, __button3_span1;

    __ = createElement("li", "list-group-item draggable d-flex", null);
    __div1 = createElement("div", null, __);
    __div1.className = DRAGGABLE_HANDLE_CLASS;
    __div1.textContent = "⣿";
    __div2 = createElement("div", "form-inline flex-grow-1", __);
    __div2_div1 = createElement("div", "flex-fill mr-3 mb-1 mb-sm-0", __div2);
    __div2_insert2 = createTextNode('', __div2);
    __div2_div3 = createElement("div", "input-group input-group-sm flex-nowrap mr-3 mb-1 mb-sm-0", __div2);
    __div2_div3_input1 = createElement("input", null, __div2_div3);
    __div2_div3_input1.type = "number";
    __div2_div3_input1.className = INPUT_CLASS_RIGHT;
    __div2_div3_input1.min = "1";
    __div2_div3_input1.max = MAX_HOURS_PER_WEEK;
    setAttribute(__div2_div3_input1, "aria-label", "Hours per week per person");
    assign(__div2_div3_input1.style, {
      width: INPUT_WIDTH_3_DIGITS
    });
    __div2_div3_div2 = createElement("div", "input-group-append", __div2_div3);
    __div2_div3_div2_span1 = createElement("span", "input-group-text", __div2_div3_div2);
    __div2_div3_div2_span1.textContent = "h/week";
    __button3 = createElement("button", "close", __);
    __button3_span1 = createElement("span", null, __button3);
    setAttribute(__button3_span1, "aria-hidden", "true");
    __button3_span1.textContent = "×";
    S.effect(function (__current) {
      return content(__div2_div1, ctrl.contributor.type === 1
      /* EXTERNAL */
      ? function () {
        var __;

        __ = createElement("input", null, null);
        __.className = INPUT_CLASS;
        setAttribute(__, "aria-label", "Name of external contributor");
        __.size = 10;
        S.effect(function (__state) {
          return bindString(ctrl.contributor.name)(__, __state);
        });
        return __;
      }() : function () {
        var __;

        __ = createElement("input", null, null);
        S.effect(function () {
          __.className = PLAINTEXT_CLASS;
          setAttribute(__, "aria-label", "Name of YouTrack user");
          __.readOnly = true;
          __.value = ctrl.name();
        });
        return __;
      }(), __current);
    }, '');
    S.effect(function (__range) {
      return insert(__range, ctrl.contributor.type === 1
      /* EXTERNAL */
      && function () {
        var __, __input1, __div2, __div2_span1;

        __ = createElement("div", "input-group input-group-sm flex-nowrap mr-3 mb-1 mb-sm-0", null);
        __input1 = createElement("input", null, __);
        __input1.type = "number";
        __input1.className = INPUT_CLASS_RIGHT;
        __input1.min = "1";
        __input1.max = MAX_PERSONS_PER_CONTRIBUTORS;
        setAttribute(__input1, "aria-label", "Number of persons");
        assign(__input1.style, {
          width: INPUT_WIDTH_3_DIGITS
        });
        __div2 = createElement("div", "input-group-append", __);
        __div2_span1 = createElement("span", "input-group-text", __div2);
        __div2_span1.textContent = "👤";
        S.effect(function (__state) {
          return bindNumber(ctrl.contributor.numMembers)(__input1, __state);
        });
        return __;
      }());
    }, {
      start: __div2_insert2,
      end: __div2_insert2
    });
    S.effect(function (__state) {
      return bindNumber(ctrl.contributor.hoursPerWeek)(__div2_div3_input1, __state);
    });
    S.effect(function () {
      __button3.type = "button";
      setAttribute(__button3, "aria-label", "Remove contributor");

      __button3.onclick = () => ctrl.remove();
    });
    return __;
  }();
}

export { ContributorView, DRAGGABLE_HANDLE_CLASS, INPUT_WIDTH_3_DIGITS, MAX_HOURS_PER_WEEK, MAX_PERSONS_PER_CONTRIBUTORS };
//# sourceMappingURL=contributor-view.js.map
