import { jsonable } from '../../utils/s.js';
import S from 's-js';
import { unreachableCase } from '../../utils/typescript.js';
import { withClassIff } from '../../utils/surplus.js';
import { ContributorCtrl } from '../contributor/contributor-ctrl.js';
import { createContributor } from '../contributor/contributor-model.js';

const EXTERNAL_CONTRIBUTOR_VALUE = 'youtrack-planning-js/external';
const DEFAULT_HOURS_PER_WEEK = 40;
const DEFAULT_NUM_MEMBERS = 1;
class ContributorsCtrl {
  constructor(contributors, youTrackUserMap) {
    this.contributors = contributors;
    this.youTrackUserMap = youTrackUserMap;
    this.newEntry = {
      hoursPerWeek: jsonable(S.value(DEFAULT_HOURS_PER_WEEK)),
      id: jsonable(S.value('')),
      name: jsonable(S.value('')),
      numMembers: jsonable(S.value(DEFAULT_NUM_MEMBERS))
    };
    this.newEntryType = S(() => this.newEntry.id() === EXTERNAL_CONTRIBUTOR_VALUE ? 1
    /* EXTERNAL */
    : 0
    /* YOU_TRACK */
    );
    this.contributorControllers = contributors.map(contributor => new ContributorCtrl(contributor, contributors, youTrackUserMap));
  }

  create() {
    const id = this.newEntry.id();
    const type = this.newEntryType();
    const sharedProperties = {
      hoursPerWeek: this.newEntry.hoursPerWeek()
    };
    let plainContributor;

    switch (type) {
      case 0
      /* YOU_TRACK */
      :
        plainContributor = Object.assign({
          type,
          id
        }, sharedProperties);
        break;

      case 1
      /* EXTERNAL */
      :
        plainContributor = Object.assign({
          type,
          name: this.newEntry.name(),
          numMembers: this.newEntry.numMembers()
        }, sharedProperties);
        this.newEntry.name('');
        this.newEntry.numMembers(DEFAULT_NUM_MEMBERS);
        break;

      default:
        return unreachableCase(type);
    }

    this.newEntry.id('');
    this.contributors.push(createContributor(plainContributor));
  }

  reset() {
    this.newEntry.id('');
  }

  withClassIffExternalContributor(addClassIfExternalContributor, ...classes) {
    const condition = S(() => this.newEntryType() === 1
    /* EXTERNAL */
    === addClassIfExternalContributor);
    return withClassIff(condition, ...classes);
  }

}

export { ContributorsCtrl, EXTERNAL_CONTRIBUTOR_VALUE };
//# sourceMappingURL=contributors-ctrl.js.map
