import { DataSignal } from 's-js';
import { CustomField, EnumBundleElement, IssueLinkType, StateBundleElement } from '../../youtrack-rest';
import { ContributorsCtrl } from '../contributors/contributors-ctrl';
import { YouTrackMetadata } from '../you-track/you-track-model';
import { Settings } from './settings-model';
/**
 * Controller for settings related to project planning (YouTrack custom fields, list of available resources, etc.).
 */
export declare class SettingsCtrl {
    readonly settings: Settings;
    readonly youTrackMetadata: () => YouTrackMetadata | undefined;
    readonly connectSignal: DataSignal<null>;
    readonly contributorsCtrl: ContributorsCtrl;
    readonly verifiedBaseUrl: () => string;
    readonly metadata: () => YouTrackMetadata;
    readonly enumFields: () => Map<string, CustomField>;
    readonly periodFields: () => Map<string, CustomField>;
    readonly stateFields: () => Map<string, CustomField>;
    readonly userFields: () => Map<string, CustomField>;
    readonly states: () => Map<string, StateBundleElement>;
    readonly types: () => Map<string, EnumBundleElement>;
    readonly directedIssueLinkTypes: () => Map<string, IssueLinkType>;
    readonly issueLinkDirectionNames: () => [string, string];
    readonly savedQueryIds: () => Set<string>;
    /**
     * Constructor.
     *
     * @param settings
     * @param youTrackMetadata
     * @param connectSignal
     */
    constructor(settings: Settings, youTrackMetadata: () => YouTrackMetadata | undefined, connectSignal: DataSignal<null>);
    static currentUri(): string;
    hrefRelativeToBaseUrl(relativePath: string): (element: HTMLAnchorElement) => void;
    hubRelativeToBaseUrlAndServiceId(relativePath: (serviceId: string) => string): (element: HTMLAnchorElement) => void;
    private mapOfCustomFieldTypes;
}
//# sourceMappingURL=settings-ctrl.d.ts.map