import { SDataArray } from 's-array';
import { DataSignal } from 's-js';
import { Plain } from '../../utils/s';
import { Contributor } from '../contributor/contributor-model';
/**
 * Non-transient state of the settings UI component.
 */
export interface Settings {
    readonly name: DataSignal<string>;
    readonly youTrackBaseUrl: DataSignal<string>;
    readonly youTrackServiceId: DataSignal<string>;
    readonly stateFieldId: DataSignal<string>;
    readonly inactiveStateIds: DataSignal<Set<string>>;
    readonly remainingEffortFieldId: DataSignal<string>;
    readonly remainingWaitFieldId: DataSignal<string>;
    readonly assigneeFieldId: DataSignal<string>;
    readonly typeFieldId: DataSignal<string>;
    readonly splittableTypeIds: DataSignal<Set<string>>;
    readonly dependsLinkTypeId: DataSignal<string>;
    readonly doesInwardDependOnOutward: DataSignal<boolean>;
    readonly savedQuery: DataSignal<string>;
    readonly overlaySavedQuery: DataSignal<string>;
    readonly contributors: SDataArray<Contributor>;
}
/**
 * Creates a new state for the settings UI component.
 */
export declare function createSettings(): Settings;
/**
 * Updates the state of the settings UI component to the given values in a plain JSON object.
 *
 * The update is performed within a single S.js transaction.
 *
 * @param settings state of the settings UI component
 * @param plain plain JSON object
 */
export declare function assignSettings(settings: Settings, plain: Plain<Settings>): void;
/**
 * Creates a new normalized plain JSON value for the given settings.
 *
 * Normalization means that the YouTrack base URL is the result of {@link normalizedBaseUrl}().
 */
export declare function toNormalizedPlainSettings(settings: Settings): Plain<Settings>;
/**
 * Returns the normalized YouTrack base URL.
 *
 * Normalization means returning a syntactically valid URL that ends with a slash (/).
 *
 * @return the normalized URL, or the empty string if the given URL is not valid
 */
export declare function normalizedBaseUrl(baseUrl: string): string;
//# sourceMappingURL=settings-model.d.ts.map