import { authorizationFor, httpGet, getMinutesPerWorkWeek } from '@fschopp/project-planning-for-you-track';
import S from 's-js';

var YouTrackRestUrl;

(function (YouTrackRestUrl) {
  YouTrackRestUrl["CUSTOM_FIELDS"] = "youtrack/api/admin/customFieldSettings/customFields";
  YouTrackRestUrl["ISSUE_LINK_TYPES"] = "youtrack/api/issueLinkTypes";
  YouTrackRestUrl["SAVED_QUERIES"] = "youtrack/api/savedQueries";
  YouTrackRestUrl["USERS"] = "youtrack/api/admin/users";
})(YouTrackRestUrl || (YouTrackRestUrl = {}));

class YouTrackCtrl {
  constructor(youTrackMetadata_, baseUrl, alertCtrl) {
    this.youTrackMetadata_ = youTrackMetadata_;
    const pendingMetadata = S.value(false);
    this.pendingMetadata = pendingMetadata;
    S(() => {
      const currentBaseUrl = baseUrl();
      const currentYouTrackMetadata = S.sample(youTrackMetadata_);

      if (currentBaseUrl.length > 0 && !S.sample(pendingMetadata) && currentYouTrackMetadata === undefined && authorizationFor(currentBaseUrl) !== undefined) {
        pendingMetadata(true);
        Promise.all([loadCustomFields(currentBaseUrl), loadIssueLinkTypes(currentBaseUrl), loadSavedSearches(currentBaseUrl), loadUsers(currentBaseUrl), getMinutesPerWorkWeek(currentBaseUrl)]).then(([customFields, issueLinkTypes, savedSearches, users, minutesPerWorkWeek]) => {
          youTrackMetadata_({
            baseUrl: currentBaseUrl,
            customFields,
            issueLinkTypes,
            savedSearches,
            users,
            minutesPerWorkWeek
          });
        }).catch(exception => alertCtrl.alert('Failed to retrieve YouTrack metadata', exception)).finally(() => pendingMetadata(false));
      }
    });
  }

}

async function loadCustomFields(baseUrl) {
  const queryParams = {
    fields: 'fieldDefaults(bundle(id,values(color(background,foreground),id,isResolved,name,ordinal))),' + 'fieldType(id),id,name'
  };
  return await httpGet(baseUrl, YouTrackRestUrl.CUSTOM_FIELDS, queryParams);
}

async function loadIssueLinkTypes(baseUrl) {
  const queryParams = {
    fields: 'directed,id,name,sourceToTarget,targetToSource'
  };
  return await httpGet(baseUrl, YouTrackRestUrl.ISSUE_LINK_TYPES, queryParams);
}

async function loadSavedSearches(baseUrl) {
  const queryParams = {
    fields: 'id,name,owner(fullName)'
  };
  return await httpGet(baseUrl, YouTrackRestUrl.SAVED_QUERIES, queryParams);
}

async function loadUsers(baseUrl) {
  const queryParams = {
    fields: 'avatarUrl,id,fullName'
  };
  return await httpGet(baseUrl, YouTrackRestUrl.USERS, queryParams);
}

export { YouTrackCtrl };
//# sourceMappingURL=you-track-ctrl.js.map
