import { SDataArray } from 's-array';
import { DataSignal } from 's-js';
export interface Jsonable {
    toJSON(): any;
}
/**
 * Makes an s.js signal jsonable by adding a `toJSON` method that extracts its value during JSONization.
 *
 * Adapted from GitHub project
 * [adamhaile/surplus-todomvc](https://github.com/adamhaile/surplus-todomvc/blob/37ffcdfca66a11365ff88aeed5db9f38b97ba2c6/src/models.ts).
 */
export declare function jsonable<T extends () => any>(s: T): T & Jsonable;
/**
 * Creates a new plain JSON value for the given value (which may contain signals or `Set` instances).
 */
export declare function toPlain<T>(source: T): Plain<T>;
declare type PlainHelper<T> = T extends SDataArray<infer U1> ? U1[] : T extends DataSignal<infer U2> ? U2 : T extends Set<infer U3> ? U3[] : T extends ({
    [P in keyof T]: T[P];
} & {
    transient: any;
}) ? {
    [P in Exclude<keyof T, 'transient'>]: PlainHelper<T[P]>;
} : T extends {
    [P in keyof T]: T[P];
} ? {
    [P in keyof T]: PlainHelper<T[P]>;
} : T;
export declare type Plain<T> = PlainHelper<PlainHelper<PlainHelper<T>>>;
export {};
//# sourceMappingURL=s.d.ts.map