/**
 * Makes an s.js signal jsonable by adding a `toJSON` method that extracts its value during JSONization.
 *
 * Adapted from GitHub project
 * [adamhaile/surplus-todomvc](https://github.com/adamhaile/surplus-todomvc/blob/37ffcdfca66a11365ff88aeed5db9f38b97ba2c6/src/models.ts).
 */
function jsonable(s) {
  const augmentedSignal = s;
  augmentedSignal.toJSON = toJSON;
  return augmentedSignal;
}

function toJSON() {
  const value = this(); // A good idea here would be to check if value.toJSON exists. But this is not public API, and we don't need this in
  // this project.

  if (value instanceof Set) {
    return [...value];
  } else {
    return value;
  }
}
/**
 * Creates a new plain JSON value for the given value (which may contain signals or `Set` instances).
 */


function toPlain(source) {
  if (typeof source === 'function' && 'toJSON' in source) {
    return toPlain(source());
  } else if (Array.isArray(source)) {
    return source.map(toPlain);
  } else if (source instanceof Set) {
    return toPlain(Array.from(source));
  } else if (typeof source === 'object' && source !== null) {
    const typedSource = source;
    const target = {};

    for (const key in typedSource) {
      if (typedSource.hasOwnProperty(key) && key !== 'transient') {
        const plainValue = toPlain(typedSource[key]);

        if (plainValue !== undefined) {
          target[key] = plainValue;
        }
      }
    }

    return target;
  } else {
    return source;
  }
}

export { jsonable, toPlain };
//# sourceMappingURL=s.js.map
