import { SDataArray } from 's-array';
import { DataSignal } from 's-js';
/**
 * One-way binds the given data-signal array to react to UI changes in the given HTML element (note the currying).
 */
export declare function sortableBindSarray<T>(sArray: SDataArray<T>, sortableOptions?: {
    [name: string]: any;
}): (element: HTMLElement) => void;
/**
 * Two-way binds the given `number` data signal with the given `<input>` element (note the currying).
 */
export declare function bindNumber(signal: DataSignal<number>): (element: HTMLInputElement) => void;
/**
 * Two-way binds the given `string` data signal with the given `<input>` element (note the currying).
 */
export declare function bindString(signal: DataSignal<string>): (element: HTMLInputElement | HTMLSelectElement) => void;
/**
 * Two-way binds the given data signal with the given `input` element (note the currying): The element is checked if
 * and only if the data signal has the given “on”-value.
 */
export declare function bindToOnValue<T>(signal: DataSignal<T>, onValue: T): (element: HTMLInputElement) => void;
/**
 * Two-way binds the given data signal with the given 'multiple' `<select>` element (note the currying).
 */
export declare function bindStringSet(signal: DataSignal<Set<string>>): (element: HTMLSelectElement) => void;
/**
 * One-way binds the presence of CSS classes on the given HTML element to react to the given signal (note the currying).
 */
export declare function withClassIff(signal: () => boolean, ...classes: string[]): (element: HTMLElement) => void;
/**
 * If the given signal is changed to the given value, focus on the given HTML element.
 */
export declare function focusOnChangeToValue<T>(signal: () => T, value: T): (element: HTMLElement) => void;
/**
 * One-way binds the href attribute to react to the given signal.
 *
 * This function is necessary because we want to remove the href attribute if the given signal is the empty URL (as
 * opposed to setting the href attribute to the empty string, which would still be shown as a link in the browser).
 */
export declare function hrefFrom(signal: () => string): (element: HTMLAnchorElement) => void;
//# sourceMappingURL=surplus.d.ts.map